@@ -41,7 +41,8 @@ enum connman_device_type {
 	CONNMAN_DEVICE_TYPE_WIFI      = 2,
 	CONNMAN_DEVICE_TYPE_WIMAX     = 3,
 	CONNMAN_DEVICE_TYPE_BLUETOOTH = 4,
-	CONNMAN_DEVICE_TYPE_GPS       = 5,
+	CONNMAN_DEVICE_TYPE_CELLULAR  = 5,
+	CONNMAN_DEVICE_TYPE_GPS       = 6,
 	CONNMAN_DEVICE_TYPE_MBM       = 14,
 	CONNMAN_DEVICE_TYPE_HSO       = 15,
 	CONNMAN_DEVICE_TYPE_NOZOMI    = 16,
@@ -70,8 +71,8 @@ const char *connman_device_get_path(struct connman_device *device);
 void connman_device_set_index(struct connman_device *device, int index);
 int connman_device_get_index(struct connman_device *device);
 void connman_device_set_interface(struct connman_device *device,
-							const char *interface);
-const char *connman_device_get_interface(struct connman_device *device);
+				const char *interface, const char *control);
+const char *connman_device_get_control(struct connman_device *device);
 
 void connman_device_set_ident(struct connman_device *device,
 						const char *ident);
@@ -89,6 +90,8 @@ int connman_device_set_carrier(struct connman_device *device,
 						connman_bool_t carrier);
 int connman_device_set_scanning(struct connman_device *device,
 						connman_bool_t scanning);
+void connman_device_cleanup_scanning(struct connman_device *device);
+
 int connman_device_set_disconnected(struct connman_device *device,
 						connman_bool_t disconnected);
 connman_bool_t connman_device_get_disconnected(struct connman_device *device);
@@ -106,6 +109,9 @@ struct connman_network *connman_device_get_network(struct connman_device *device
 							const char *identifier);
 int connman_device_remove_network(struct connman_device *device,
 							const char *identifier);
+void connman_device_remove_all_networks(struct connman_device *device);
+
+void connman_device_schedule_scan(struct connman_device *device);
 
 int connman_device_register(struct connman_device *device);
 void connman_device_unregister(struct connman_device *device);
