@@ -442,13 +442,18 @@ struct connman_device *connman_inet_create_device(int index)
 	if (devname == NULL)
 		return NULL;
 
+	if (__connman_element_device_isfiltered(devname) == TRUE) {
+		connman_info("Ignoring interface %s (filtered)", devname);
+		return NULL;
+	}
+
 	__connman_udev_get_devtype(devname);
 
 	type = __connman_inet_get_device_type(index);
 
 	switch (type) {
 	case CONNMAN_DEVICE_TYPE_UNKNOWN:
-		connman_info("Ignoring network interface %s", devname);
+		connman_info("Ignoring interface %s (type unknown)", devname);
 		g_free(devname);
 		return NULL;
 	case CONNMAN_DEVICE_TYPE_ETHERNET:
@@ -464,6 +469,7 @@ struct connman_device *connman_inet_create_device(int index)
 	case CONNMAN_DEVICE_TYPE_HUAWEI:
 	case CONNMAN_DEVICE_TYPE_NOVATEL:
 	case CONNMAN_DEVICE_TYPE_VENDOR:
+	case CONNMAN_DEVICE_TYPE_CELLULAR:
 		name = strdup(devname);
 		break;
 	case CONNMAN_DEVICE_TYPE_MBM:
@@ -496,6 +502,7 @@ struct connman_device *connman_inet_create_device(int index)
 		ident = index2ident(index, NULL);
 		break;
 	case CONNMAN_DEVICE_TYPE_BLUETOOTH:
+	case CONNMAN_DEVICE_TYPE_CELLULAR:
 		mode = CONNMAN_DEVICE_MODE_NETWORK_MULTIPLE;
 		break;
 	case CONNMAN_DEVICE_TYPE_MBM:
@@ -512,7 +519,7 @@ struct connman_device *connman_inet_create_device(int index)
 
 	if (ident != NULL) {
 		connman_device_set_ident(device, ident);
-		g_free(ident);
+		free(ident);
 	}
 
 	connman_device_set_string(device, "Address", addr);
@@ -520,8 +527,8 @@ struct connman_device *connman_inet_create_device(int index)
 done:
 	g_free(devname);
 	g_free(node);
-	g_free(name);
-	g_free(addr);
+	free(name);
+	free(addr);
 
 	return device;
 }
